[Vm-dev] [commit][3632] CogVM source as per VMMaker.oscog-eem.1700

commits at squeakvm.org commits at squeakvm.org
Thu Feb 25 00:55:58 UTC 2016


Revision: 3632
Author:   eliot
Date:     2016-02-24 16:55:55 -0800 (Wed, 24 Feb 2016)
Log Message:
-----------
CogVM source as per VMMaker.oscog-eem.1700

Fix special selector arithmetic and comparison in the 64-bit Cogit.  My original
code for genJumpNotSmallIntegersIn:andScratchReg: merely jumped if the tags
differed, hence not jumping if both arguments were SmallFloat64s (or both
Characters).  The new code requires an additional scratch register;
hence add genJumpNotSmallIntegersIn:andScratch:scratch:.

Modified Paths:
--------------
    branches/Cog/nsspur64src/vm/cogit.h
    branches/Cog/nsspur64src/vm/cogitX64.c
    branches/Cog/nsspursrc/vm/cogit.h
    branches/Cog/nsspursrc/vm/cogitARMv5.c
    branches/Cog/nsspursrc/vm/cogitIA32.c
    branches/Cog/nsspursrc/vm/cogitMIPSEL.c
    branches/Cog/spur64src/vm/cogit.h
    branches/Cog/spur64src/vm/cogitX64.c
    branches/Cog/spursistasrc/vm/cogit.h
    branches/Cog/spursistasrc/vm/cogitARMv5.c
    branches/Cog/spursistasrc/vm/cogitIA32.c
    branches/Cog/spursistasrc/vm/cogitMIPSEL.c
    branches/Cog/spursrc/vm/cogit.h
    branches/Cog/spursrc/vm/cogitARMv5.c
    branches/Cog/spursrc/vm/cogitIA32.c
    branches/Cog/spursrc/vm/cogitMIPSEL.c
    branches/Cog/src/vm/cogit.h
    branches/Cog/src/vm/cogitARMv5.c
    branches/Cog/src/vm/cogitIA32.c
    branches/Cog/src/vm/cogitMIPSEL.c

Property Changed:
----------------
    branches/Cog/platforms/Cross/vm/sqSCCSVersion.h

Modified: branches/Cog/nsspur64src/vm/cogit.h
===================================================================
--- branches/Cog/nsspur64src/vm/cogit.h	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/nsspur64src/vm/cogit.h	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
 
 

Modified: branches/Cog/nsspur64src/vm/cogitX64.c
===================================================================
--- branches/Cog/nsspursrc/vm/cogit.h	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/nsspursrc/vm/cogit.h	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
 
 

Modified: branches/Cog/nsspursrc/vm/cogitARMv5.c
===================================================================
--- branches/Cog/nsspursrc/vm/cogitARMv5.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/nsspursrc/vm/cogitARMv5.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -27092,7 +27092,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -27333,7 +27333,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/nsspursrc/vm/cogitIA32.c
===================================================================
--- branches/Cog/nsspursrc/vm/cogitIA32.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/nsspursrc/vm/cogitIA32.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -9626,12 +9626,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -24290,7 +24290,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -24509,7 +24509,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/nsspursrc/vm/cogitMIPSEL.c
===================================================================
--- branches/Cog/nsspursrc/vm/cogitMIPSEL.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/nsspursrc/vm/cogitMIPSEL.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -5738,12 +5738,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -24514,7 +24514,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -24733,7 +24733,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}


Property changes on: branches/Cog/platforms/Cross/vm/sqSCCSVersion.h
___________________________________________________________________
Modified: checkindate
   - Wed Feb 24 11:19:58 PST 2016
   + Wed Feb 24 16:53:34 PST 2016

Modified: branches/Cog/spur64src/vm/cogit.h
===================================================================
--- branches/Cog/spur64src/vm/cogit.h	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spur64src/vm/cogit.h	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
 
 

Modified: branches/Cog/spur64src/vm/cogitX64.c
===================================================================
--- branches/Cog/spursistasrc/vm/cogit.h	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursistasrc/vm/cogit.h	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
 
 

Modified: branches/Cog/spursistasrc/vm/cogitARMv5.c
===================================================================
--- branches/Cog/spursistasrc/vm/cogitARMv5.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursistasrc/vm/cogitARMv5.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -10421,12 +10421,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -24483,7 +24483,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -24657,7 +24657,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -28524,7 +28524,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/spursistasrc/vm/cogitIA32.c
===================================================================
--- branches/Cog/spursistasrc/vm/cogitIA32.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursistasrc/vm/cogitIA32.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -21854,7 +21854,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -22013,7 +22013,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -25690,7 +25690,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/spursistasrc/vm/cogitMIPSEL.c
===================================================================
--- branches/Cog/spursistasrc/vm/cogitMIPSEL.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursistasrc/vm/cogitMIPSEL.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "SistaStackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -5602,12 +5602,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -22085,7 +22085,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -22244,7 +22244,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -25910,7 +25910,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/spursrc/vm/cogit.h
===================================================================
--- branches/Cog/spursrc/vm/cogit.h	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursrc/vm/cogit.h	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
 
 

Modified: branches/Cog/spursrc/vm/cogitARMv5.c
===================================================================
--- branches/Cog/spursrc/vm/cogitARMv5.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursrc/vm/cogitARMv5.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -24557,7 +24557,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -24804,7 +24804,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/spursrc/vm/cogitIA32.c
===================================================================
--- branches/Cog/spursrc/vm/cogitIA32.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursrc/vm/cogitIA32.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -21885,7 +21885,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -22110,7 +22110,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/spursrc/vm/cogitMIPSEL.c
===================================================================
--- branches/Cog/spursrc/vm/cogitMIPSEL.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spursrc/vm/cogitMIPSEL.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -22099,7 +22099,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -22324,7 +22324,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/src/vm/cogit.h
===================================================================
--- branches/Cog/src/vm/cogit.h	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/src/vm/cogit.h	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,5 +1,5 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
 
 

Modified: branches/Cog/src/vm/cogitARMv5.c
===================================================================
--- branches/Cog/src/vm/cogitARMv5.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/src/vm/cogitARMv5.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1697 uuid: 03f07782-25a7-4178-8528-7f8638ca30ff " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -9817,12 +9817,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    sqInt delta;
+    usqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    sqInt location;
-    sqInt mapEntry;
+    usqInt location;
+    usqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -21761,7 +21761,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -22008,7 +22008,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/src/vm/cogitIA32.c
===================================================================
--- branches/Cog/src/vm/cogitIA32.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/src/vm/cogitIA32.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -8891,12 +8891,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -19564,7 +19564,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -19789,7 +19789,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}

Modified: branches/Cog/src/vm/cogitMIPSEL.c
===================================================================
--- branches/Cog/src/vm/cogitMIPSEL.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/src/vm/cogitMIPSEL.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -5010,12 +5010,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    sqInt delta;
+    usqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    sqInt location;
-    sqInt mapEntry;
+    usqInt location;
+    usqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -19765,7 +19765,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
@@ -19990,7 +19990,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}
 	else {
-		/* begin genJumpNotSmallIntegersIn:andScratchReg: */
+		/* begin genJumpNotSmallIntegersIn:andScratch:scratch: */
 		genoperandoperand(AndRR, ReceiverResultReg, TempReg);
 		jumpNotSmallInts = genJumpNotSmallIntegerInScratchReg(TempReg);
 	}



More information about the Vm-dev mailing list
--- branches/Cog/nsspur64src/vm/cogitX64.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/nsspur64src/vm/cogitX64.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -769,7 +769,7 @@
 static AbstractInstruction * NoDbgRegParms genJumpIsSmallIntegerValuescratch(sqInt aRegister, sqInt scratchReg);
 static AbstractInstruction * NoDbgRegParms genJumpNotCharacterscratchReg(sqInt reg, sqInt scratch);
 static AbstractInstruction * NoDbgRegParms genJumpNotSmallFloatValueBitsscratch(sqInt reg, sqInt exponent);
-static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegersInandScratchReg(sqInt aRegister, sqInt scratchReg);
+static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegersInandScratchscratch(sqInt aRegister, sqInt scratchA, sqInt scratchB);
 static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegerValuescratch(sqInt aRegister, sqInt scratchReg);
 static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegerscratchReg(sqInt reg, sqInt scratch);
 static AbstractInstruction * NoDbgRegParms genJumpSmallIntegerscratchReg(sqInt reg, sqInt scratch);
@@ -5883,12 +5883,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    sqInt delta;
+    usqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    sqInt location;
-    sqInt mapEntry;
+    usqInt location;
+    usqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -12414,24 +12414,45 @@
 }
 
 
 /*	Generate a compare and branch to test if aRegister and scratchReg contains
 	other than SmallIntegers,
-	i.e. don't branch if both aRegister and scratchReg contain SmallIntegers.
-	Answer the jump. Destroy scratchReg if required. */
+	i.e. don't branch if both aRegister and scratchA contain SmallIntegers.
+	Answer the jump. Destroy scratchA and scratchB if required. */
+/*	Map SmallIntegers to 0 in scratchA & scratchB, add and jump non-zero. */
 
-	/* CogObjectRepresentationFor64BitSpur>>#genJumpNotSmallIntegersIn:andScratchReg: */
+	/* CogObjectRepresentationFor64BitSpur>>#genJumpNotSmallIntegersIn:andScratch:scratch: */
 static AbstractInstruction * NoDbgRegParms
-genJumpNotSmallIntegersInandScratchReg(sqInt aRegister, sqInt scratchReg)
+genJumpNotSmallIntegersInandScratchscratch(sqInt aRegister, sqInt scratchA, sqInt scratchB)
 {
     AbstractInstruction *anInstruction;
+    AbstractInstruction *anInstruction1;
+    AbstractInstruction *anInstruction2;
+    AbstractInstruction *anInstruction3;
     sqInt quickConstant;
+    sqInt quickConstant1;
+    sqInt quickConstant2;
+    sqInt quickConstant3;
 
-	return (/* begin XorR:R: */
-		genoperandoperand(XorRR, aRegister, scratchReg),
+	return (/* begin MoveR:R: */
+		genoperandoperand(MoveRR, aRegister, scratchB),
+		/* begin SubCq:R: */
+		(quickConstant2 = smallIntegerTag()),
+		/* begin gen:quickConstant:operand: */
+		(anInstruction2 = genoperandoperand(SubCqR, quickConstant2, scratchA)),
+		/* begin SubCq:R: */
+		(quickConstant3 = smallIntegerTag()),
+		/* begin gen:quickConstant:operand: */
+		(anInstruction3 = genoperandoperand(SubCqR, quickConstant3, scratchB)),
 		/* begin AndCq:R: */
 		(quickConstant = tagMask()),
 		/* begin gen:quickConstant:operand: */
-		(anInstruction = genoperandoperand(AndCqR, quickConstant, scratchReg)),
+		(anInstruction = genoperandoperand(AndCqR, quickConstant, scratchA)),
+		/* begin AndCq:R: */
+		(quickConstant1 = tagMask()),
+		/* begin gen:quickConstant:operand: */
+		(anInstruction1 = genoperandoperand(AndCqR, quickConstant1, scratchB)),
+		/* begin AddR:R: */
+		genoperandoperand(AddRR, scratchA, scratchB),
 		/* begin JumpNonZero: */
 		genConditionalBranchoperand(JumpNonZero, ((sqInt)0)));
 }
@@ -25637,7 +25658,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerscratchReg(TempReg, TempReg);
 	}
 	else {
-		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchReg(ReceiverResultReg, TempReg);
+		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchscratch(ReceiverResultReg, TempReg, ClassReg);
 	}
 	
 	switch ((primDescriptor->opcode)) {
@@ -25855,7 +25876,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerscratchReg(TempReg, TempReg);
 	}
 	else {
-		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchReg(ReceiverResultReg, TempReg);
+		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchscratch(ReceiverResultReg, TempReg, ClassReg);
 	}
 	if (argIsInt) {
 		if (annotateInst) {
@@ -12414,24 +12414,45 @@
 
 
-/*	Generate a compare and branch to test if aRegister and scratchReg contains
+/*	Generate a compare and branch to test if aRegister and scratchA contains
 	other than SmallIntegers,

Modified: branches/Cog/nsspursrc/vm/cogit.h
===================================================================
--- branches/Cog/spur64src/vm/cogitX64.c	2016-02-24 19:25:16 UTC (rev 3631)
+++ branches/Cog/spur64src/vm/cogitX64.c	2016-02-25 00:55:55 UTC (rev 3632)
@@ -1,9 +1,9 @@
 /* Automatically generated by
-	CCodeGenerator VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	CCodeGenerator VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
    from
-	StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777
+	StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4
  */
-static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1699 uuid: 186ebd51-28ef-4e7f-8411-96b61577b777 " __DATE__ ;
+static char __buildInfo[] = "StackToRegisterMappingCogit VMMaker.oscog-eem.1700 uuid: 4efaff50-3cc1-4840-8195-df0e306eb5a4 " __DATE__ ;
 char *__cogitBuildInfo = __buildInfo;
 
 
@@ -749,7 +749,7 @@
 static AbstractInstruction * NoDbgRegParms genJumpIsSmallIntegerValuescratch(sqInt aRegister, sqInt scratchReg);
 static AbstractInstruction * NoDbgRegParms genJumpNotCharacterscratchReg(sqInt reg, sqInt scratch);
 static AbstractInstruction * NoDbgRegParms genJumpNotSmallFloatValueBitsscratch(sqInt reg, sqInt exponent);
-static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegersInandScratchReg(sqInt aRegister, sqInt scratchReg);
+static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegersInandScratchscratch(sqInt aRegister, sqInt scratchA, sqInt scratchB);
 static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegerValuescratch(sqInt aRegister, sqInt scratchReg);
 static AbstractInstruction * NoDbgRegParms genJumpNotSmallIntegerscratchReg(sqInt reg, sqInt scratch);
 static AbstractInstruction * NoDbgRegParms genJumpSmallIntegerscratchReg(sqInt reg, sqInt scratch);
@@ -3286,7 +3286,7 @@
 closedPICRefersToUnmarkedObject(CogMethod *cPIC)
 {
     sqInt i;
-    sqInt object;
+    usqInt object;
     sqInt pc;
 
 	if (!((isImmediate((cPIC->selector)))
@@ -5425,12 +5425,12 @@
 generateMapAtstart(sqInt addressOrNull, sqInt startAddress)
 {
     unsigned char annotation;
-    usqInt delta;
+    sqInt delta;
     sqInt i;
     AbstractInstruction *instruction;
     sqInt length;
-    usqInt location;
-    usqInt mapEntry;
+    sqInt location;
+    sqInt mapEntry;
     sqInt maxDelta;
     usqInt mcpc;
 
@@ -11322,24 +11322,45 @@
 }
 
 
 /*	Generate a compare and branch to test if aRegister and scratchReg contains
 	other than SmallIntegers,
-	i.e. don't branch if both aRegister and scratchReg contain SmallIntegers.
-	Answer the jump. Destroy scratchReg if required. */
+	i.e. don't branch if both aRegister and scratchA contain SmallIntegers.
+	Answer the jump. Destroy scratchA and scratchB if required. */
+/*	Map SmallIntegers to 0 in scratchA & scratchB, add and jump non-zero. */
 
-	/* CogObjectRepresentationFor64BitSpur>>#genJumpNotSmallIntegersIn:andScratchReg: */
+	/* CogObjectRepresentationFor64BitSpur>>#genJumpNotSmallIntegersIn:andScratch:scratch: */
 static AbstractInstruction * NoDbgRegParms
-genJumpNotSmallIntegersInandScratchReg(sqInt aRegister, sqInt scratchReg)
+genJumpNotSmallIntegersInandScratchscratch(sqInt aRegister, sqInt scratchA, sqInt scratchB)
 {
     AbstractInstruction *anInstruction;
+    AbstractInstruction *anInstruction1;
+    AbstractInstruction *anInstruction2;
+    AbstractInstruction *anInstruction3;
     sqInt quickConstant;
+    sqInt quickConstant1;
+    sqInt quickConstant2;
+    sqInt quickConstant3;
 
-	return (/* begin XorR:R: */
-		genoperandoperand(XorRR, aRegister, scratchReg),
+	return (/* begin MoveR:R: */
+		genoperandoperand(MoveRR, aRegister, scratchB),
+		/* begin SubCq:R: */
+		(quickConstant2 = smallIntegerTag()),
+		/* begin gen:quickConstant:operand: */
+		(anInstruction2 = genoperandoperand(SubCqR, quickConstant2, scratchA)),
+		/* begin SubCq:R: */
+		(quickConstant3 = smallIntegerTag()),
+		/* begin gen:quickConstant:operand: */
+		(anInstruction3 = genoperandoperand(SubCqR, quickConstant3, scratchB)),
 		/* begin AndCq:R: */
 		(quickConstant = tagMask()),
 		/* begin gen:quickConstant:operand: */
-		(anInstruction = genoperandoperand(AndCqR, quickConstant, scratchReg)),
+		(anInstruction = genoperandoperand(AndCqR, quickConstant, scratchA)),
+		/* begin AndCq:R: */
+		(quickConstant1 = tagMask()),
+		/* begin gen:quickConstant:operand: */
+		(anInstruction1 = genoperandoperand(AndCqR, quickConstant1, scratchB)),
+		/* begin AddR:R: */
+		genoperandoperand(AddRR, scratchA, scratchB),
 		/* begin JumpNonZero: */
 		genConditionalBranchoperand(JumpNonZero, ((sqInt)0)));
 }
@@ -23255,7 +23276,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerscratchReg(TempReg, TempReg);
 	}
 	else {
-		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchReg(ReceiverResultReg, TempReg);
+		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchscratch(ReceiverResultReg, TempReg, ClassReg);
 	}
 	
 	switch ((primDescriptor->opcode)) {
@@ -23479,7 +23500,7 @@
 		jumpNotSmallInts = genJumpNotSmallIntegerscratchReg(TempReg, TempReg);
 	}
 	else {
-		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchReg(ReceiverResultReg, TempReg);
+		jumpNotSmallInts = genJumpNotSmallIntegersInandScratchscratch(ReceiverResultReg, TempReg, ClassReg);
 	}
 	if (argIsInt) {
 		if (annotateInst) {
@@ -11322,24 +11322,45 @@
 
 
-/*	Generate a compare and branch to test if aRegister and scratchReg contains
+/*	Generate a compare and branch to test if aRegister and scratchA contains
 	other than SmallIntegers,

Modified: branches/Cog/spursistasrc/vm/cogit.h
===================================================================